import { fetch } from '../fetch.js';
export function authorization_functions(config) {
    async function check_authorization(subject_or_tuple, action, object) {
        let tuples;
        if (Array.isArray(subject_or_tuple)) {
            tuples = subject_or_tuple;
            if (tuples.length === 0) {
                return [];
            }
        }
        else {
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            tuples = [{ subject: subject_or_tuple, action: action, object: object }];
        }
        const response = await fetch(config.AUTHORIZATION_SERVER + '/authorize', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'X-Authorization-PSK': config.AUTHORIZATION_PSK,
            },
            body: JSON.stringify(tuples),
        });
        if (response.status === 200) {
            const result = await response.json();
            if (Array.isArray(subject_or_tuple)) {
                return result.map((r) => ({
                    result: r.result ?? false,
                    reason: r.reason,
                }));
            }
            else {
                return { result: result[0].result ?? false, reason: result[0].reason };
            }
        }
        else {
            throw new Error(`Unexpected Status Code from Authorization Server: ${response.status}`);
        }
    }
    async function update_relations(add, remove) {
        const result = await fetch(config.AUTHORIZATION_SERVER + '/relations/update', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'X-Authorization-PSK': config.AUTHORIZATION_PSK,
            },
            body: JSON.stringify({ add, remove }),
        });
        if (result.status !== 200) {
            throw new Error(await result.text());
        }
    }
    async function relate(subject_or_tuples, relation, object) {
        let tuples;
        if (Array.isArray(subject_or_tuples)) {
            tuples = subject_or_tuples;
        }
        else {
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            tuples = [{ subject: subject_or_tuples, relation: relation, object: object }];
        }
        await update_relations(tuples, []);
    }
    async function unrelate(subject_or_tuples, relation, object) {
        let tuples;
        if (Array.isArray(subject_or_tuples)) {
            tuples = subject_or_tuples;
        }
        else {
            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
            tuples = [{ subject: subject_or_tuples, relation: relation, object: object }];
        }
        await update_relations([], tuples);
    }
    async function query(subject, relation, object) {
        const response = await fetch(config.AUTHORIZATION_SERVER + '/relations/query', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
                'X-Authorization-PSK': config.AUTHORIZATION_PSK,
            },
            body: JSON.stringify({ subject, relation, object }),
        });
        if (response.status === 200) {
            return (await response.json()) ?? [];
        }
        else {
            throw new Error(await response.text());
        }
    }
    return { check_authorization, update_relations, relate, unrelate, query };
}
//# sourceMappingURL=authorization.js.map