import { DataSource } from 'typeorm';
export class AbstractApplicationDataSource {
    constructor(options) {
        this.connected = false;
        this._dataSource = new DataSource(options);
        this.repositories = this.createRepositories();
    }
    initializeRepositories(repositories, entityManager) {
        for (const key in repositories) {
            repositories[key].initialize(entityManager);
        }
    }
    async initialize(options) {
        options ??= this._dataSource.options;
        if (this._dataSource.isInitialized) {
            await this._dataSource.destroy();
            this._dataSource = new DataSource(options);
        }
        else if (options !== this._dataSource.options) {
            this._dataSource = new DataSource(options);
        }
        await this._dataSource.initialize();
        this.connected = true;
        this.entityManager = this._dataSource.createEntityManager();
        await this.initializeRepositories(this.repositories, this.entityManager);
    }
    async teardown() {
        if (!this._dataSource?.isInitialized)
            throw new Error('Data Source has not been initialized!');
        await this._dataSource.destroy();
        this.connected = false;
    }
    get dataSource() {
        return this._dataSource;
    }
    async transaction(runInTransaction) {
        return this._dataSource?.transaction(async (entityManager) => {
            const repositories = this.createRepositories();
            await this.initializeRepositories(repositories, entityManager);
            return runInTransaction(repositories);
        });
    }
}
//# sourceMappingURL=abstractDataSource.js.map